pub enum HardwareMeasurementResult {
MeasuredPass,
MeasuredFail,
NotMeasured,
}Expand description
Whether a physical-provider observation can satisfy the hardware gate.
Variants
MeasuredPass
A physical adapter was measured and every contract passed.
MeasuredFail
A physical adapter was measured and at least one contract failed.
NotMeasured
No qualifying physical adapter was measured.