compare_materialized_to_reference

Function compare_materialized_to_reference 

pub fn compare_materialized_to_reference(
    reference: &HostPhasorField,
    candidate: &HostPhasorField,
    tolerances: DifferentialTolerances,
) -> Result<DifferentialReport, DifferentialError>
Compares one materialized provider result with the deterministic f64 oracle.

Provider results use the same component, amplitude, phase-floor, wrapped phase, and squared-magnitude reporting path as compare_dense_to_reference. The candidate is expected to be a materialized f32 Tensor field represented by the runtime’s host phasor container.