pub struct TilePlan { /* private fields */ }Expand description
Complete deterministic tiling chosen before any Tensor submission.
Implementations
Sourceimpl TilePlan
impl TilePlan
Sourcepub fn new(
plane: SamplingPlane,
wavenumber_rad_per_metre: f64,
budget: PhaseBudget,
profile: TileProfile,
) -> Result<Self, LoweringError>
pub fn new( plane: SamplingPlane, wavenumber_rad_per_metre: f64, budget: PhaseBudget, profile: TileProfile, ) -> Result<Self, LoweringError>
Splits a plane under phase, element, segment, and byte limits.
Sourcepub fn tile_rows(&self) -> usize
pub fn tile_rows(&self) -> usize
Returns the nominal row count used before clipping edge tiles.
Sourcepub fn tile_columns(&self) -> usize
pub fn tile_columns(&self) -> usize
Returns the nominal column count used before clipping edge tiles.
Sourcepub fn conservative_max_abs_phase_rad(&self) -> f64
pub fn conservative_max_abs_phase_rad(&self) -> f64
Returns the conservative k * tile_radius bound.