TileProfile

Struct TileProfile 

pub struct TileProfile {
    pub supports_f32: bool,
    pub max_elements_per_tile: usize,
    pub max_segment_bytes: u64,
    pub max_segments_per_tensor: usize,
    pub max_tensor_bytes: u64,
    pub max_result_bytes: u64,
}
Provider and allocation limits used to partition and admit a plane.

Fields

supports_f32: bool

Whether the selected provider admits canonical numbers/f32.

max_elements_per_tile: usize

Largest logical element count for one tile Tensor.

max_segment_bytes: u64

Largest byte count in one resident segment.

max_segments_per_tensor: usize

Largest segment count for one tile Tensor.

max_tensor_bytes: u64

Largest total byte count for one tile Tensor.

max_result_bytes: u64

Largest combined byte count for the final real and imaginary planes.